Index: third_party/WebKit/Source/bindings/core/v8/ScriptController.cpp |
diff --git a/third_party/WebKit/Source/bindings/core/v8/ScriptController.cpp b/third_party/WebKit/Source/bindings/core/v8/ScriptController.cpp |
index 4a354bc7fb70624629aa131c0352746359a4041c..068b0223885c8b172dfd6b92ccef6a37c11acfc0 100644 |
--- a/third_party/WebKit/Source/bindings/core/v8/ScriptController.cpp |
+++ b/third_party/WebKit/Source/bindings/core/v8/ScriptController.cpp |
@@ -131,13 +131,6 @@ void ScriptController::clearScriptObjects() |
} |
} |
-void ScriptController::clearForClose() |
-{ |
- double start = currentTime(); |
- m_windowProxyManager->clearForClose(); |
- Platform::current()->histogramCustomCounts("WebCore.ScriptController.clearForClose", (currentTime() - start) * 1000, 0, 10000, 50); |
-} |
- |
void ScriptController::updateSecurityOrigin(SecurityOrigin* origin) |
{ |
m_windowProxyManager->mainWorldProxy()->updateSecurityOrigin(origin); |
@@ -406,10 +399,10 @@ void ScriptController::clearWindowProxy() |
double start = currentTime(); |
// The V8 context must be available for |clearScriptObjects()|. |
// The below call must be before |clearForNavigation()| which disposes the V8 context. |
clearScriptObjects(); |
- m_windowProxyManager->clearForNavigation(); |
+ m_windowProxyManager->clearWindowProxy(); |
Platform::current()->histogramCustomCounts("WebCore.ScriptController.clearWindowProxy", (currentTime() - start) * 1000, 0, 10000, 50); |
} |
@@ -406,10 +399,10 @@ void ScriptController::clearWindowProxy() |
double start = currentTime(); |
// The V8 context must be available for |clearScriptObjects()|. |
- // The below call must be before |clearForNavigation()| which disposes the V8 context. |
+ // The below call must be before |clearWindowProxy()| which disposes the V8 context. |
clearScriptObjects(); |